@@ -83,8 +83,7 @@ class WebSocketApp(object):
           The 2nd argument is utf-8 string which we get from the server.
           The 3rd argument is data type. ABNF.OPCODE_TEXT or ABNF.OPCODE_BINARY will be came.
           The 4th argument is continue flag. if 0, the data continue
-        keep_running: a boolean flag indicating whether the app's main loop
-          should keep running, defaults to True
+        keep_running: this parameter is obosleted and ignored it.
         get_mask_key: a callable to produce new mask keys,
           see the WebSocket.set_mask_key's docstring for more information
         subprotocols: array of available sub protocols. default is None.
@@ -100,7 +99,7 @@ class WebSocketApp(object):
         self.on_ping = on_ping
         self.on_pong = on_pong
         self.on_cont_message = on_cont_message
-        self.keep_running = keep_running
+        self.keep_running = False
         self.get_mask_key = get_mask_key
         self.sock = None
         self.last_ping_tm = 0
@@ -174,6 +173,7 @@ class WebSocketApp(object):
             raise WebSocketException("socket is already opened")
         thread = None
         close_frame = None
+        self.keep_running = True
 
         try:
             self.sock = WebSocket(
@@ -213,7 +213,7 @@ class WebSocketApp(object):
                         self.last_pong_tm = time.time()
                         self._callback(self.on_pong, frame.data)
                     elif op_code == ABNF.OPCODE_CONT and self.on_cont_message:
-                        self._callback(self.on_data, data,
+                        self._callback(self.on_data, frame.data,
                                        frame.opcode, frame.fin)
                         self._callback(self.on_cont_message,
                                        frame.data, frame.fin)
@@ -237,7 +237,7 @@ class WebSocketApp(object):
             if thread and thread.isAlive():
                 event.set()
                 thread.join()
-                self.keep_running = False
+            self.keep_running = False
             self.sock.close()
             close_args = self._get_close_args(
                 close_frame.data if close_frame else None)
